Welcome to Ladybug-rhino's documentation!
=========================================

.. image:: http://www.ladybug.tools/assets/img/ladybug.png

Ladybug-rhino is a library for communicating between Ladybug Tools core libraries and Rhinoceros CAD.

This library is used by both the Grasshopper and Rhino plugins to communicate with
the ladybug core Python library. Note that this library has dependencies
on Rhino SDK and Grasshopper SDK. It is NOT intended to be run with cPython with
the exception of running the CLI.

Installation
============

``pip install -U ladybug-rhino``

CLI Docs
=============

For command line interface documentation and API documentation see the pages below.


.. toctree::
   :maxdepth: 2

   cli/index


ladybug_rhino
=============

.. toctree::
  :maxdepth: 4

  modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
